<div class="card mb-4 mt-3">
	<div class="card-header">
		{{ _('CKAN Version and Plugins') }}
	</div>
	<div class="card-body">
		<table class="table table-borderless">
			<thead>
				<tr>
					<th scope="col">Site Title</th>
					<th scope="col">CKAN Version</th>
					<th scope="col">Default Language</th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td>{{ data.status_show.site_title }}</td>
					<td>{{ data.status_show.ckan_version }}</td>
					<td>{{ data.status_show.locale_default }}</td>
				</tr>
			</tbody>
		</table>

		<div class="accordion">
			<div class="accordion-item mb-3">
				<h2 class="accordion-header" id="extensions-heading">
					<button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
						data-bs-target="#extensionsCollapse" aria-expanded="false" aria-controls="extensionsCollapse">
						{{ _('Extensions') }}
					</button>
				</h2>
				<div id="extensionsCollapse" class="accordion-collapse collapse" aria-labelledby="extensions-heading">
					<div class="accordion-body">
						<ul class="list-group">
							{% for extension in data.status_show.extensions %}
							<li class="list-group-item">
								{{ extension }}
							</li>
							{% endfor %}
						</ul>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>